@@ -56,6 +56,21 @@ class CardsGenerator:
 
         if not self._template:
             type(self)._template = Image.open(PLUGIN_SETTINGS["TEMPLATE"])
+            self._check_canvas_position()
+
+    def _check_canvas_position(self):
+        template_w, template_h = self._template.size
+        canvas_w = PLUGIN_SETTINGS["CANVAS_WIDTH"] + PLUGIN_SETTINGS["CANVAS_LEFT"]
+        canvas_h = PLUGIN_SETTINGS["CANVAS_HEIGHT"] + PLUGIN_SETTINGS["CANVAS_TOP"]
+
+        if canvas_w > template_w or canvas_h > template_h:
+            logger.warning(
+                (
+                    "pelican.plugins.social_cards: Template size is {}x{}, "
+                    "bottom right corner of canvas is at ({}, {})\n"
+                    "Part of the text may be drawn outside of image borders."
+                ).format(template_w, template_h, canvas_w, canvas_h)
+            )
 
     def _get_article_title(self, article):
         metadata_title = getattr(article, f"{PLUGIN_SETTINGS['KEY_NAME']}_text", None)
@@ -86,7 +101,7 @@ class CardsGenerator:
                 card_stem = card_stem[:trim]
         card_stem = card_stem.strip("-")
 
-        card_name = f"{card_stem}.png"
+        card_name = f"{card_stem}.{PLUGIN_SETTINGS['FORMAT_EXTENSION']}"
         card_path = PLUGIN_SETTINGS["PATH"] / card_name
         return card_path
 
@@ -123,6 +138,8 @@ class CardsGenerator:
         font_fill = PLUGIN_SETTINGS["FONT_FILL"]
         canvas_width = PLUGIN_SETTINGS["CANVAS_WIDTH"]
         canvas_height = PLUGIN_SETTINGS["CANVAS_HEIGHT"]
+        outline_size = PLUGIN_SETTINGS["FONT_OUTLINE_SIZE"]
+        outline_fill = PLUGIN_SETTINGS["FONT_OUTLINE_FILL"]
 
         if text_box.width > canvas_width or text_box.height > canvas_height:
             logger.warning(
@@ -144,11 +161,22 @@ class CardsGenerator:
 
         for line in text:
             current_x = self._calc_current_x(text_box, line)
-            draw.text((current_x, current_y), line, font=self._font, fill=font_fill)
+            draw.text(
+                (current_x, current_y),
+                line,
+                font=self._font,
+                fill=font_fill,
+                stroke_width=outline_size,
+                stroke_fill=outline_fill,
+            )
             current_y += text_box.line_height
         return img
 
     def create_for_object(self, content_object):
+        logger.debug(
+            f"pelican-social-cards: generating image for {content_object.source_path}"
+        )
+
         target_path = self._get_card_path(content_object)
 
         attr_name = f"{PLUGIN_SETTINGS['KEY_NAME']}_source"
